==> classpath-0.16.tar.gz: classpath-0.16/org/omg/CORBA/DynSequence.java <==
/* DynSequence.java --
   Copyright (C) 2005 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package org.omg.CORBA;

import org.omg.CORBA.DynAnyPackage.InvalidSeq;

/**
 * Represents the {@link DynAny}, holding the CORBA sequence
 * (an array with the flexible length).
 *
 * @author Audrius Meskauskas, Lithuania (AudriusA@Bioinformatics.org)
 */
public interface DynSequence
  extends DynAny
{
  /**
   * Get the elements of the enclosed sequence.
   */
  Any[] get_elements();

  /**
   * Returns the number of elements, stored in the sequence.
   * @return
   */
  int length();

  /**
   * Sets the length of this sequence to the given value.
   *
   * @param l the new length of the sequence.
   */
  void length(int l);

  /**
   * Set the elements from of the enclosed array of Anys.
   *
   * @throws InvalidSeq if the passed array contains the
   * elements of the different type.
   */
  void set_elements(Any[] an_array)
             throws InvalidSeq;
}

==> classpath-0.93.tar.gz: classpath-0.93/org/omg/CORBA/DynSequence.java <==
/* DynSequence.java --
   Copyright (C) 2005, 2006 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package org.omg.CORBA;

import org.omg.CORBA.DynAnyPackage.InvalidSeq;

/**
 * Represents the {@link DynAny}, holding the CORBA sequence
 * (an array with the flexible length).
 *
 * @author Audrius Meskauskas, Lithuania (AudriusA@Bioinformatics.org)
 */
public interface DynSequence
  extends DynAny
{
  /**
   * Get the elements of the enclosed sequence.
   */
  Any[] get_elements();

  /**
   * Returns the number of elements, stored in the sequence.
   * @return the length of the sequence
   */
  int length();

  /**
   * Sets the length of this sequence to the given value.
   *
   * @param l the new length of the sequence.
   */
  void length(int l);

  /**
   * Set the elements from of the enclosed array of Anys.
   *
   * @throws InvalidSeq if the passed array contains the
   * elements of the different type.
   */
  void set_elements(Any[] an_array)
             throws InvalidSeq;
}
